from _typeshed import Incomplete

class Schemas:
    schemas: Incomplete
    pretty: Incomplete
    def __init__(self, discovery) -> None: ...
    def prettyPrintByName(self, name): ...
    def prettyPrintSchema(self, schema): ...
    def get(self, name, default: Incomplete | None = ...): ...

class _SchemaToStruct:
    value: Incomplete
    string: Incomplete
    schema: Incomplete
    dent: Incomplete
    from_cache: Incomplete
    seen: Incomplete
    def __init__(self, schema, seen, dent: int = ...) -> None: ...
    def emit(self, text) -> None: ...
    def emitBegin(self, text) -> None: ...
    def emitEnd(self, text, comment) -> None: ...
    def indent(self) -> None: ...
    def undent(self) -> None: ...
    def to_str(self, from_cache): ...
