__credits__: str

def parse_mime_type(mime_type): ...
def parse_media_range(range): ...
def fitness_and_quality_parsed(mime_type, parsed_ranges): ...
def quality_parsed(mime_type, parsed_ranges): ...
def quality(mime_type, ranges): ...
def best_match(supported, header): ...
