from _typeshed import Incomplete

def init(
    argv,
    name,
    version,
    doc,
    filename,
    scope: Incomplete | None = ...,
    parents=...,
    discovery_filename: Incomplete | None = ...,
): ...
