from _typeshed import Incomplete

from googleapiclient.errors import HttpError as HttpError

LOGGER: Incomplete
dump_request_response: bool

class Model:
    def request(self, headers, path_params, query_params, body_value) -> None: ...
    def response(self, resp, content) -> None: ...

class BaseModel(Model):
    accept: Incomplete
    content_type: Incomplete
    no_content_response: Incomplete
    alt_param: Incomplete
    def request(self, headers, path_params, query_params, body_value): ...
    def response(self, resp, content): ...
    def serialize(self, body_value) -> None: ...
    def deserialize(self, content) -> None: ...

class JsonModel(BaseModel):
    accept: str
    content_type: str
    alt_param: str
    def __init__(self, data_wrapper: bool = ...) -> None: ...
    def serialize(self, body_value): ...
    def deserialize(self, content): ...
    @property
    def no_content_response(self): ...

class RawModel(JsonModel):
    accept: str
    content_type: str
    alt_param: Incomplete
    def deserialize(self, content): ...
    @property
    def no_content_response(self): ...

class MediaModel(JsonModel):
    accept: str
    content_type: str
    alt_param: str
    def deserialize(self, content): ...
    @property
    def no_content_response(self): ...

class ProtocolBufferModel(BaseModel):
    accept: str
    content_type: str
    alt_param: str
    def __init__(self, protocol_buffer) -> None: ...
    def serialize(self, body_value): ...
    def deserialize(self, content): ...
    @property
    def no_content_response(self): ...

def makepatch(original, modified): ...
