# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['apiclient-stubs', 'googleapiclient-stubs']

package_data = \
{'': ['*'],
 'googleapiclient-stubs': ['_apis/*',
                           '_apis/abusiveexperiencereport/*',
                           '_apis/abusiveexperiencereport/v1/*',
                           '_apis/acceleratedmobilepageurl/*',
                           '_apis/acceleratedmobilepageurl/v1/*',
                           '_apis/accessapproval/*',
                           '_apis/accessapproval/v1/*',
                           '_apis/accesscontextmanager/*',
                           '_apis/accesscontextmanager/v1/*',
                           '_apis/accesscontextmanager/v1beta/*',
                           '_apis/adexchangebuyer/*',
                           '_apis/adexchangebuyer/v1_2/*',
                           '_apis/adexchangebuyer/v1_3/*',
                           '_apis/adexchangebuyer/v1_4/*',
                           '_apis/adexchangebuyer2/*',
                           '_apis/adexchangebuyer2/v2beta1/*',
                           '_apis/adexperiencereport/*',
                           '_apis/adexperiencereport/v1/*',
                           '_apis/admin/*',
                           '_apis/admin/datatransfer_v1/*',
                           '_apis/admin/directory_v1/*',
                           '_apis/admin/reports_v1/*',
                           '_apis/admob/*',
                           '_apis/admob/v1/*',
                           '_apis/admob/v1beta/*',
                           '_apis/adsense/*',
                           '_apis/adsense/v2/*',
                           '_apis/adsensehost/*',
                           '_apis/adsensehost/v4_1/*',
                           '_apis/alertcenter/*',
                           '_apis/alertcenter/v1beta1/*',
                           '_apis/analytics/*',
                           '_apis/analytics/v3/*',
                           '_apis/analyticsadmin/*',
                           '_apis/analyticsadmin/v1alpha/*',
                           '_apis/analyticsdata/*',
                           '_apis/analyticsdata/v1alpha/*',
                           '_apis/analyticsdata/v1beta/*',
                           '_apis/analyticshub/*',
                           '_apis/analyticshub/v1/*',
                           '_apis/analyticshub/v1beta1/*',
                           '_apis/analyticsreporting/*',
                           '_apis/analyticsreporting/v4/*',
                           '_apis/androiddeviceprovisioning/*',
                           '_apis/androiddeviceprovisioning/v1/*',
                           '_apis/androidenterprise/*',
                           '_apis/androidenterprise/v1/*',
                           '_apis/androidmanagement/*',
                           '_apis/androidmanagement/v1/*',
                           '_apis/androidpublisher/*',
                           '_apis/androidpublisher/v3/*',
                           '_apis/apigateway/*',
                           '_apis/apigateway/v1/*',
                           '_apis/apigateway/v1beta/*',
                           '_apis/apigee/*',
                           '_apis/apigee/v1/*',
                           '_apis/apigeeregistry/*',
                           '_apis/apigeeregistry/v1/*',
                           '_apis/apikeys/*',
                           '_apis/apikeys/v2/*',
                           '_apis/appengine/*',
                           '_apis/appengine/v1/*',
                           '_apis/appengine/v1alpha/*',
                           '_apis/appengine/v1beta/*',
                           '_apis/appengine/v1beta4/*',
                           '_apis/appengine/v1beta5/*',
                           '_apis/area120tables/*',
                           '_apis/area120tables/v1alpha1/*',
                           '_apis/artifactregistry/*',
                           '_apis/artifactregistry/v1/*',
                           '_apis/artifactregistry/v1beta1/*',
                           '_apis/artifactregistry/v1beta2/*',
                           '_apis/assuredworkloads/*',
                           '_apis/assuredworkloads/v1/*',
                           '_apis/assuredworkloads/v1beta1/*',
                           '_apis/authorizedbuyersmarketplace/*',
                           '_apis/authorizedbuyersmarketplace/v1/*',
                           '_apis/baremetalsolution/*',
                           '_apis/baremetalsolution/v1/*',
                           '_apis/baremetalsolution/v1alpha1/*',
                           '_apis/baremetalsolution/v2/*',
                           '_apis/beyondcorp/*',
                           '_apis/beyondcorp/v1/*',
                           '_apis/beyondcorp/v1alpha/*',
                           '_apis/bigquery/*',
                           '_apis/bigquery/v2/*',
                           '_apis/bigqueryconnection/*',
                           '_apis/bigqueryconnection/v1beta1/*',
                           '_apis/bigquerydatatransfer/*',
                           '_apis/bigquerydatatransfer/v1/*',
                           '_apis/bigqueryreservation/*',
                           '_apis/bigqueryreservation/v1/*',
                           '_apis/bigqueryreservation/v1alpha2/*',
                           '_apis/bigqueryreservation/v1beta1/*',
                           '_apis/bigtableadmin/*',
                           '_apis/bigtableadmin/v1/*',
                           '_apis/bigtableadmin/v2/*',
                           '_apis/billingbudgets/*',
                           '_apis/billingbudgets/v1/*',
                           '_apis/billingbudgets/v1beta1/*',
                           '_apis/binaryauthorization/*',
                           '_apis/binaryauthorization/v1/*',
                           '_apis/binaryauthorization/v1beta1/*',
                           '_apis/blogger/*',
                           '_apis/blogger/v2/*',
                           '_apis/blogger/v3/*',
                           '_apis/books/*',
                           '_apis/books/v1/*',
                           '_apis/businessprofileperformance/*',
                           '_apis/businessprofileperformance/v1/*',
                           '_apis/calendar/*',
                           '_apis/calendar/v3/*',
                           '_apis/certificatemanager/*',
                           '_apis/certificatemanager/v1/*',
                           '_apis/chat/*',
                           '_apis/chat/v1/*',
                           '_apis/chromemanagement/*',
                           '_apis/chromemanagement/v1/*',
                           '_apis/chromepolicy/*',
                           '_apis/chromepolicy/v1/*',
                           '_apis/chromeuxreport/*',
                           '_apis/chromeuxreport/v1/*',
                           '_apis/civicinfo/*',
                           '_apis/civicinfo/v2/*',
                           '_apis/classroom/*',
                           '_apis/classroom/v1/*',
                           '_apis/cloudasset/*',
                           '_apis/cloudasset/v1/*',
                           '_apis/cloudasset/v1beta1/*',
                           '_apis/cloudasset/v1p1beta1/*',
                           '_apis/cloudasset/v1p4beta1/*',
                           '_apis/cloudasset/v1p5beta1/*',
                           '_apis/cloudasset/v1p7beta1/*',
                           '_apis/cloudbilling/*',
                           '_apis/cloudbilling/v1/*',
                           '_apis/cloudbilling/v1beta/*',
                           '_apis/cloudbuild/*',
                           '_apis/cloudbuild/v1/*',
                           '_apis/cloudbuild/v1alpha1/*',
                           '_apis/cloudbuild/v1alpha2/*',
                           '_apis/cloudbuild/v1beta1/*',
                           '_apis/cloudchannel/*',
                           '_apis/cloudchannel/v1/*',
                           '_apis/cloudcommerceprocurement/*',
                           '_apis/cloudcommerceprocurement/v1/*',
                           '_apis/clouddebugger/*',
                           '_apis/clouddebugger/v2/*',
                           '_apis/clouddeploy/*',
                           '_apis/clouddeploy/v1/*',
                           '_apis/clouderrorreporting/*',
                           '_apis/clouderrorreporting/v1beta1/*',
                           '_apis/cloudfunctions/*',
                           '_apis/cloudfunctions/v1/*',
                           '_apis/cloudfunctions/v2/*',
                           '_apis/cloudfunctions/v2alpha/*',
                           '_apis/cloudfunctions/v2beta/*',
                           '_apis/cloudidentity/*',
                           '_apis/cloudidentity/v1/*',
                           '_apis/cloudidentity/v1beta1/*',
                           '_apis/cloudiot/*',
                           '_apis/cloudiot/v1/*',
                           '_apis/cloudkms/*',
                           '_apis/cloudkms/v1/*',
                           '_apis/cloudprofiler/*',
                           '_apis/cloudprofiler/v2/*',
                           '_apis/cloudresourcemanager/*',
                           '_apis/cloudresourcemanager/v1/*',
                           '_apis/cloudresourcemanager/v1beta1/*',
                           '_apis/cloudresourcemanager/v2/*',
                           '_apis/cloudresourcemanager/v2beta1/*',
                           '_apis/cloudresourcemanager/v3/*',
                           '_apis/cloudscheduler/*',
                           '_apis/cloudscheduler/v1/*',
                           '_apis/cloudscheduler/v1beta1/*',
                           '_apis/cloudsearch/*',
                           '_apis/cloudsearch/v1/*',
                           '_apis/cloudshell/*',
                           '_apis/cloudshell/v1/*',
                           '_apis/cloudshell/v1alpha1/*',
                           '_apis/cloudsupport/*',
                           '_apis/cloudsupport/v2beta/*',
                           '_apis/cloudtasks/*',
                           '_apis/cloudtasks/v2/*',
                           '_apis/cloudtasks/v2beta2/*',
                           '_apis/cloudtasks/v2beta3/*',
                           '_apis/cloudtrace/*',
                           '_apis/cloudtrace/v1/*',
                           '_apis/cloudtrace/v2/*',
                           '_apis/cloudtrace/v2beta1/*',
                           '_apis/composer/*',
                           '_apis/composer/v1/*',
                           '_apis/composer/v1beta1/*',
                           '_apis/compute/*',
                           '_apis/compute/alpha/*',
                           '_apis/compute/beta/*',
                           '_apis/compute/v1/*',
                           '_apis/connectors/*',
                           '_apis/connectors/v1/*',
                           '_apis/connectors/v2/*',
                           '_apis/contactcenterinsights/*',
                           '_apis/contactcenterinsights/v1/*',
                           '_apis/container/*',
                           '_apis/container/v1/*',
                           '_apis/container/v1beta1/*',
                           '_apis/containeranalysis/*',
                           '_apis/containeranalysis/v1/*',
                           '_apis/containeranalysis/v1alpha1/*',
                           '_apis/containeranalysis/v1beta1/*',
                           '_apis/content/*',
                           '_apis/content/v2/*',
                           '_apis/content/v2_1/*',
                           '_apis/contentwarehouse/*',
                           '_apis/contentwarehouse/v1/*',
                           '_apis/customsearch/*',
                           '_apis/customsearch/v1/*',
                           '_apis/datacatalog/*',
                           '_apis/datacatalog/v1/*',
                           '_apis/datacatalog/v1beta1/*',
                           '_apis/dataflow/*',
                           '_apis/dataflow/v1b3/*',
                           '_apis/datafusion/*',
                           '_apis/datafusion/v1/*',
                           '_apis/datafusion/v1beta1/*',
                           '_apis/datalabeling/*',
                           '_apis/datalabeling/v1beta1/*',
                           '_apis/datamigration/*',
                           '_apis/datamigration/v1/*',
                           '_apis/datamigration/v1beta1/*',
                           '_apis/datapipelines/*',
                           '_apis/datapipelines/v1/*',
                           '_apis/dataplex/*',
                           '_apis/dataplex/v1/*',
                           '_apis/dataproc/*',
                           '_apis/dataproc/v1/*',
                           '_apis/dataproc/v1beta2/*',
                           '_apis/datastore/*',
                           '_apis/datastore/v1/*',
                           '_apis/datastore/v1beta1/*',
                           '_apis/datastore/v1beta3/*',
                           '_apis/datastream/*',
                           '_apis/datastream/v1/*',
                           '_apis/datastream/v1alpha1/*',
                           '_apis/deploymentmanager/*',
                           '_apis/deploymentmanager/alpha/*',
                           '_apis/deploymentmanager/v2/*',
                           '_apis/deploymentmanager/v2beta/*',
                           '_apis/dfareporting/*',
                           '_apis/dfareporting/v3_3/*',
                           '_apis/dfareporting/v3_4/*',
                           '_apis/dfareporting/v3_5/*',
                           '_apis/dfareporting/v4/*',
                           '_apis/dialogflow/*',
                           '_apis/dialogflow/v2/*',
                           '_apis/dialogflow/v2beta1/*',
                           '_apis/dialogflow/v3/*',
                           '_apis/dialogflow/v3beta1/*',
                           '_apis/digitalassetlinks/*',
                           '_apis/digitalassetlinks/v1/*',
                           '_apis/discovery/*',
                           '_apis/discovery/v1/*',
                           '_apis/displayvideo/*',
                           '_apis/displayvideo/v1/*',
                           '_apis/displayvideo/v2/*',
                           '_apis/dlp/*',
                           '_apis/dlp/v2/*',
                           '_apis/dns/*',
                           '_apis/dns/v1/*',
                           '_apis/dns/v1beta2/*',
                           '_apis/dns/v2/*',
                           '_apis/docs/*',
                           '_apis/docs/v1/*',
                           '_apis/documentai/*',
                           '_apis/documentai/v1/*',
                           '_apis/documentai/v1beta2/*',
                           '_apis/documentai/v1beta3/*',
                           '_apis/domains/*',
                           '_apis/domains/v1/*',
                           '_apis/domains/v1alpha2/*',
                           '_apis/domains/v1beta1/*',
                           '_apis/domainsrdap/*',
                           '_apis/domainsrdap/v1/*',
                           '_apis/doubleclickbidmanager/*',
                           '_apis/doubleclickbidmanager/v1/*',
                           '_apis/doubleclickbidmanager/v1_1/*',
                           '_apis/doubleclickbidmanager/v2/*',
                           '_apis/doubleclicksearch/*',
                           '_apis/doubleclicksearch/v2/*',
                           '_apis/drive/*',
                           '_apis/drive/v2/*',
                           '_apis/drive/v3/*',
                           '_apis/driveactivity/*',
                           '_apis/driveactivity/v2/*',
                           '_apis/drivelabels/*',
                           '_apis/drivelabels/v2/*',
                           '_apis/drivelabels/v2beta/*',
                           '_apis/essentialcontacts/*',
                           '_apis/essentialcontacts/v1/*',
                           '_apis/eventarc/*',
                           '_apis/eventarc/v1/*',
                           '_apis/eventarc/v1beta1/*',
                           '_apis/factchecktools/*',
                           '_apis/factchecktools/v1alpha1/*',
                           '_apis/fcm/*',
                           '_apis/fcm/v1/*',
                           '_apis/fcmdata/*',
                           '_apis/fcmdata/v1beta1/*',
                           '_apis/file/*',
                           '_apis/file/v1/*',
                           '_apis/file/v1beta1/*',
                           '_apis/firebase/*',
                           '_apis/firebase/v1beta1/*',
                           '_apis/firebaseappcheck/*',
                           '_apis/firebaseappcheck/v1/*',
                           '_apis/firebaseappcheck/v1beta/*',
                           '_apis/firebasedatabase/*',
                           '_apis/firebasedatabase/v1beta/*',
                           '_apis/firebasedynamiclinks/*',
                           '_apis/firebasedynamiclinks/v1/*',
                           '_apis/firebasehosting/*',
                           '_apis/firebasehosting/v1/*',
                           '_apis/firebasehosting/v1beta1/*',
                           '_apis/firebaseml/*',
                           '_apis/firebaseml/v1/*',
                           '_apis/firebaseml/v1beta2/*',
                           '_apis/firebaserules/*',
                           '_apis/firebaserules/v1/*',
                           '_apis/firebasestorage/*',
                           '_apis/firebasestorage/v1beta/*',
                           '_apis/firestore/*',
                           '_apis/firestore/v1/*',
                           '_apis/firestore/v1beta1/*',
                           '_apis/firestore/v1beta2/*',
                           '_apis/fitness/*',
                           '_apis/fitness/v1/*',
                           '_apis/forms/*',
                           '_apis/forms/v1/*',
                           '_apis/games/*',
                           '_apis/games/v1/*',
                           '_apis/gamesConfiguration/*',
                           '_apis/gamesConfiguration/v1configuration/*',
                           '_apis/gamesManagement/*',
                           '_apis/gamesManagement/v1management/*',
                           '_apis/gameservices/*',
                           '_apis/gameservices/v1/*',
                           '_apis/gameservices/v1beta/*',
                           '_apis/genomics/*',
                           '_apis/genomics/v1/*',
                           '_apis/genomics/v1alpha2/*',
                           '_apis/genomics/v2alpha1/*',
                           '_apis/gkebackup/*',
                           '_apis/gkebackup/v1/*',
                           '_apis/gkehub/*',
                           '_apis/gkehub/v1/*',
                           '_apis/gkehub/v1alpha/*',
                           '_apis/gkehub/v1alpha2/*',
                           '_apis/gkehub/v1beta/*',
                           '_apis/gkehub/v1beta1/*',
                           '_apis/gkehub/v2alpha/*',
                           '_apis/gmail/*',
                           '_apis/gmail/v1/*',
                           '_apis/gmailpostmastertools/*',
                           '_apis/gmailpostmastertools/v1/*',
                           '_apis/gmailpostmastertools/v1beta1/*',
                           '_apis/groupsmigration/*',
                           '_apis/groupsmigration/v1/*',
                           '_apis/groupssettings/*',
                           '_apis/groupssettings/v1/*',
                           '_apis/healthcare/*',
                           '_apis/healthcare/v1/*',
                           '_apis/healthcare/v1beta1/*',
                           '_apis/homegraph/*',
                           '_apis/homegraph/v1/*',
                           '_apis/iam/*',
                           '_apis/iam/v1/*',
                           '_apis/iam/v2beta/*',
                           '_apis/iamcredentials/*',
                           '_apis/iamcredentials/v1/*',
                           '_apis/iap/*',
                           '_apis/iap/v1/*',
                           '_apis/iap/v1beta1/*',
                           '_apis/ideahub/*',
                           '_apis/ideahub/v1alpha/*',
                           '_apis/ideahub/v1beta/*',
                           '_apis/identitytoolkit/*',
                           '_apis/identitytoolkit/v1/*',
                           '_apis/identitytoolkit/v2/*',
                           '_apis/identitytoolkit/v3/*',
                           '_apis/ids/*',
                           '_apis/ids/v1/*',
                           '_apis/indexing/*',
                           '_apis/indexing/v3/*',
                           '_apis/integrations/*',
                           '_apis/integrations/v1alpha/*',
                           '_apis/jobs/*',
                           '_apis/jobs/v2/*',
                           '_apis/jobs/v3/*',
                           '_apis/jobs/v3p1beta1/*',
                           '_apis/jobs/v4/*',
                           '_apis/keep/*',
                           '_apis/keep/v1/*',
                           '_apis/kgsearch/*',
                           '_apis/kgsearch/v1/*',
                           '_apis/language/*',
                           '_apis/language/v1/*',
                           '_apis/language/v1beta1/*',
                           '_apis/language/v1beta2/*',
                           '_apis/libraryagent/*',
                           '_apis/libraryagent/v1/*',
                           '_apis/licensing/*',
                           '_apis/licensing/v1/*',
                           '_apis/lifesciences/*',
                           '_apis/lifesciences/v2beta/*',
                           '_apis/localservices/*',
                           '_apis/localservices/v1/*',
                           '_apis/logging/*',
                           '_apis/logging/v2/*',
                           '_apis/managedidentities/*',
                           '_apis/managedidentities/v1/*',
                           '_apis/managedidentities/v1alpha1/*',
                           '_apis/managedidentities/v1beta1/*',
                           '_apis/manufacturers/*',
                           '_apis/manufacturers/v1/*',
                           '_apis/memcache/*',
                           '_apis/memcache/v1/*',
                           '_apis/memcache/v1beta2/*',
                           '_apis/metastore/*',
                           '_apis/metastore/v1alpha/*',
                           '_apis/metastore/v1beta/*',
                           '_apis/ml/*',
                           '_apis/ml/v1/*',
                           '_apis/monitoring/*',
                           '_apis/monitoring/v1/*',
                           '_apis/monitoring/v3/*',
                           '_apis/mybusinessaccountmanagement/*',
                           '_apis/mybusinessaccountmanagement/v1/*',
                           '_apis/mybusinessbusinesscalls/*',
                           '_apis/mybusinessbusinesscalls/v1/*',
                           '_apis/mybusinessbusinessinformation/*',
                           '_apis/mybusinessbusinessinformation/v1/*',
                           '_apis/mybusinesslodging/*',
                           '_apis/mybusinesslodging/v1/*',
                           '_apis/mybusinessnotifications/*',
                           '_apis/mybusinessnotifications/v1/*',
                           '_apis/mybusinessplaceactions/*',
                           '_apis/mybusinessplaceactions/v1/*',
                           '_apis/mybusinessqanda/*',
                           '_apis/mybusinessqanda/v1/*',
                           '_apis/mybusinessverifications/*',
                           '_apis/mybusinessverifications/v1/*',
                           '_apis/networkconnectivity/*',
                           '_apis/networkconnectivity/v1/*',
                           '_apis/networkconnectivity/v1alpha1/*',
                           '_apis/networkmanagement/*',
                           '_apis/networkmanagement/v1/*',
                           '_apis/networkmanagement/v1beta1/*',
                           '_apis/networksecurity/*',
                           '_apis/networksecurity/v1/*',
                           '_apis/networksecurity/v1beta1/*',
                           '_apis/networkservices/*',
                           '_apis/networkservices/v1/*',
                           '_apis/networkservices/v1beta1/*',
                           '_apis/notebooks/*',
                           '_apis/notebooks/v1/*',
                           '_apis/oauth2/*',
                           '_apis/oauth2/v2/*',
                           '_apis/ondemandscanning/*',
                           '_apis/ondemandscanning/v1/*',
                           '_apis/ondemandscanning/v1beta1/*',
                           '_apis/orgpolicy/*',
                           '_apis/orgpolicy/v2/*',
                           '_apis/osconfig/*',
                           '_apis/osconfig/v1/*',
                           '_apis/osconfig/v1alpha/*',
                           '_apis/osconfig/v1beta/*',
                           '_apis/oslogin/*',
                           '_apis/oslogin/v1/*',
                           '_apis/oslogin/v1alpha/*',
                           '_apis/oslogin/v1beta/*',
                           '_apis/pagespeedonline/*',
                           '_apis/pagespeedonline/v5/*',
                           '_apis/paymentsresellersubscription/*',
                           '_apis/paymentsresellersubscription/v1/*',
                           '_apis/people/*',
                           '_apis/people/v1/*',
                           '_apis/playablelocations/*',
                           '_apis/playablelocations/v3/*',
                           '_apis/playcustomapp/*',
                           '_apis/playcustomapp/v1/*',
                           '_apis/playdeveloperreporting/*',
                           '_apis/playdeveloperreporting/v1alpha1/*',
                           '_apis/playdeveloperreporting/v1beta1/*',
                           '_apis/playintegrity/*',
                           '_apis/playintegrity/v1/*',
                           '_apis/policyanalyzer/*',
                           '_apis/policyanalyzer/v1/*',
                           '_apis/policyanalyzer/v1beta1/*',
                           '_apis/policysimulator/*',
                           '_apis/policysimulator/v1/*',
                           '_apis/policysimulator/v1alpha/*',
                           '_apis/policysimulator/v1beta1/*',
                           '_apis/policytroubleshooter/*',
                           '_apis/policytroubleshooter/v1/*',
                           '_apis/policytroubleshooter/v1beta/*',
                           '_apis/poly/*',
                           '_apis/poly/v1/*',
                           '_apis/privateca/*',
                           '_apis/privateca/v1/*',
                           '_apis/privateca/v1beta1/*',
                           '_apis/prod_tt_sasportal/*',
                           '_apis/prod_tt_sasportal/v1alpha1/*',
                           '_apis/pubsub/*',
                           '_apis/pubsub/v1/*',
                           '_apis/pubsub/v1beta1a/*',
                           '_apis/pubsub/v1beta2/*',
                           '_apis/pubsublite/*',
                           '_apis/pubsublite/v1/*',
                           '_apis/realtimebidding/*',
                           '_apis/realtimebidding/v1/*',
                           '_apis/realtimebidding/v1alpha/*',
                           '_apis/recaptchaenterprise/*',
                           '_apis/recaptchaenterprise/v1/*',
                           '_apis/recommendationengine/*',
                           '_apis/recommendationengine/v1beta1/*',
                           '_apis/recommender/*',
                           '_apis/recommender/v1/*',
                           '_apis/recommender/v1beta1/*',
                           '_apis/redis/*',
                           '_apis/redis/v1/*',
                           '_apis/redis/v1beta1/*',
                           '_apis/remotebuildexecution/*',
                           '_apis/remotebuildexecution/v1/*',
                           '_apis/remotebuildexecution/v1alpha/*',
                           '_apis/remotebuildexecution/v2/*',
                           '_apis/reseller/*',
                           '_apis/reseller/v1/*',
                           '_apis/resourcesettings/*',
                           '_apis/resourcesettings/v1/*',
                           '_apis/retail/*',
                           '_apis/retail/v2/*',
                           '_apis/retail/v2alpha/*',
                           '_apis/retail/v2beta/*',
                           '_apis/run/*',
                           '_apis/run/v1/*',
                           '_apis/run/v1alpha1/*',
                           '_apis/run/v1beta1/*',
                           '_apis/run/v2/*',
                           '_apis/runtimeconfig/*',
                           '_apis/runtimeconfig/v1/*',
                           '_apis/runtimeconfig/v1beta1/*',
                           '_apis/safebrowsing/*',
                           '_apis/safebrowsing/v4/*',
                           '_apis/sasportal/*',
                           '_apis/sasportal/v1alpha1/*',
                           '_apis/script/*',
                           '_apis/script/v1/*',
                           '_apis/searchconsole/*',
                           '_apis/searchconsole/v1/*',
                           '_apis/secretmanager/*',
                           '_apis/secretmanager/v1/*',
                           '_apis/secretmanager/v1beta1/*',
                           '_apis/securitycenter/*',
                           '_apis/securitycenter/v1/*',
                           '_apis/securitycenter/v1beta1/*',
                           '_apis/securitycenter/v1beta2/*',
                           '_apis/serviceconsumermanagement/*',
                           '_apis/serviceconsumermanagement/v1/*',
                           '_apis/serviceconsumermanagement/v1beta1/*',
                           '_apis/servicecontrol/*',
                           '_apis/servicecontrol/v1/*',
                           '_apis/servicecontrol/v2/*',
                           '_apis/servicedirectory/*',
                           '_apis/servicedirectory/v1/*',
                           '_apis/servicedirectory/v1beta1/*',
                           '_apis/servicemanagement/*',
                           '_apis/servicemanagement/v1/*',
                           '_apis/servicenetworking/*',
                           '_apis/servicenetworking/v1/*',
                           '_apis/servicenetworking/v1beta/*',
                           '_apis/serviceusage/*',
                           '_apis/serviceusage/v1/*',
                           '_apis/serviceusage/v1beta1/*',
                           '_apis/sheets/*',
                           '_apis/sheets/v4/*',
                           '_apis/siteVerification/*',
                           '_apis/siteVerification/v1/*',
                           '_apis/slides/*',
                           '_apis/slides/v1/*',
                           '_apis/smartdevicemanagement/*',
                           '_apis/smartdevicemanagement/v1/*',
                           '_apis/sourcerepo/*',
                           '_apis/sourcerepo/v1/*',
                           '_apis/spanner/*',
                           '_apis/spanner/v1/*',
                           '_apis/speech/*',
                           '_apis/speech/v1/*',
                           '_apis/speech/v1p1beta1/*',
                           '_apis/speech/v2beta1/*',
                           '_apis/sqladmin/*',
                           '_apis/sqladmin/v1/*',
                           '_apis/sqladmin/v1beta4/*',
                           '_apis/storage/*',
                           '_apis/storage/v1/*',
                           '_apis/storagetransfer/*',
                           '_apis/storagetransfer/v1/*',
                           '_apis/streetviewpublish/*',
                           '_apis/streetviewpublish/v1/*',
                           '_apis/sts/*',
                           '_apis/sts/v1/*',
                           '_apis/sts/v1beta/*',
                           '_apis/tagmanager/*',
                           '_apis/tagmanager/v1/*',
                           '_apis/tagmanager/v2/*',
                           '_apis/tasks/*',
                           '_apis/tasks/v1/*',
                           '_apis/testing/*',
                           '_apis/testing/v1/*',
                           '_apis/texttospeech/*',
                           '_apis/texttospeech/v1/*',
                           '_apis/texttospeech/v1beta1/*',
                           '_apis/toolresults/*',
                           '_apis/toolresults/v1beta3/*',
                           '_apis/tpu/*',
                           '_apis/tpu/v1/*',
                           '_apis/tpu/v1alpha1/*',
                           '_apis/tpu/v2alpha1/*',
                           '_apis/trafficdirector/*',
                           '_apis/trafficdirector/v2/*',
                           '_apis/transcoder/*',
                           '_apis/transcoder/v1/*',
                           '_apis/transcoder/v1beta1/*',
                           '_apis/translate/*',
                           '_apis/translate/v2/*',
                           '_apis/translate/v3/*',
                           '_apis/translate/v3beta1/*',
                           '_apis/vault/*',
                           '_apis/vault/v1/*',
                           '_apis/vectortile/*',
                           '_apis/vectortile/v1/*',
                           '_apis/verifiedaccess/*',
                           '_apis/verifiedaccess/v1/*',
                           '_apis/verifiedaccess/v2/*',
                           '_apis/versionhistory/*',
                           '_apis/versionhistory/v1/*',
                           '_apis/videointelligence/*',
                           '_apis/videointelligence/v1/*',
                           '_apis/videointelligence/v1beta2/*',
                           '_apis/videointelligence/v1p1beta1/*',
                           '_apis/videointelligence/v1p2beta1/*',
                           '_apis/videointelligence/v1p3beta1/*',
                           '_apis/vision/*',
                           '_apis/vision/v1/*',
                           '_apis/vision/v1p1beta1/*',
                           '_apis/vision/v1p2beta1/*',
                           '_apis/vmmigration/*',
                           '_apis/vmmigration/v1/*',
                           '_apis/vmmigration/v1alpha1/*',
                           '_apis/webfonts/*',
                           '_apis/webfonts/v1/*',
                           '_apis/webmasters/*',
                           '_apis/webmasters/v3/*',
                           '_apis/webrisk/*',
                           '_apis/webrisk/v1/*',
                           '_apis/websecurityscanner/*',
                           '_apis/websecurityscanner/v1/*',
                           '_apis/websecurityscanner/v1alpha/*',
                           '_apis/websecurityscanner/v1beta/*',
                           '_apis/workflowexecutions/*',
                           '_apis/workflowexecutions/v1/*',
                           '_apis/workflowexecutions/v1beta/*',
                           '_apis/workflows/*',
                           '_apis/workflows/v1/*',
                           '_apis/workflows/v1beta/*',
                           '_apis/youtube/*',
                           '_apis/youtube/v3/*',
                           '_apis/youtubeAnalytics/*',
                           '_apis/youtubeAnalytics/v1/*',
                           '_apis/youtubeAnalytics/v2/*',
                           '_apis/youtubereporting/*',
                           '_apis/youtubereporting/v1/*',
                           'discovery_cache/*']}

install_requires = \
['google-api-python-client>=2.64.0', 'typing-extensions>=3.10.0']

setup_kwargs = {
    'name': 'google-api-python-client-stubs',
    'version': '1.14.1',
    'description': 'Type stubs for google-api-python-client',
    'long_description': '# Type stubs for google-api-python-client\n\n[![PyPI version](https://badge.fury.io/py/google-api-python-client-stubs.svg)](https://badge.fury.io/py/google-api-python-client-stubs)\n\nThis package provides type stubs for the [google-api-python-client](https://github.com/googleapis/google-api-python-client) library. \nIt allows you to type check usage of the library with e.g. [mypy](http://mypy-lang.org/) and will also improve autocomplete in many editors.\n\n**This is in no way affiliated with Google.**\n\nThe stubs were generated automatically based on Google\'s [Discovery Documents](https://developers.google.com/discovery/v1/reference/apis), that are bundled with google-api-python-client as of v2.\n\nIf you find incorrect annotations, please create an issue.\n\n## Installation\n\n```shell script\n$ pip install google-api-python-client-stubs\n```\n\n## Caveats\n\n### Performance\nThe stubs contain a separate overload of `googleapiclient.discovery.build` for each service and version (see `discovery.pyi`). \nThis can lead to slow type inference for this function. Mypy will generally be pretty fast after the first run,\nbut you might experience slow autocomplete. If you\'re experiencing this problem you can bypass type inference with explicit annotations, \ne.g. `sheets_service: SheetsResource = build("sheets", "v4")` instead of `sheets_service = build("sheets", "v4")`.\nSee the next section for some caveats to this approach.\n\n### Explicit annotations\nThe `google-api-python-client-stubs` is quite dynamic. \nAll resources are just instances of a single class with dynamically attached methods\nand the requests and responses are just dictionaries. The way this is annotated is with\nclasses and [TypedDicts](https://docs.python.org/3/library/typing.html#typing.TypedDict)\nthat don\'t exist in the actual library, only in the stub files. This means you *cannot* use any of these types at runtime, it *will* cause your code to crash.\nIf you rely solely on type inference, this is not an issue, but as soon as you want to explicitly\nannotate a variable, argument or return type in your code with one of these types, you must follow these rules:\n1. Either put `from __future__ import annotations` at the top of your file or surround the annotations with quotes. \nThis ensures that Python doesn\'t attempt to evaluate the types at runtime. \nNote that the import is only supported in Python 3.7 and above.\n2. Only import the types inside an `if typing.TYPE_CHECKING` block. This ensures that the imports are only evaluated during\ntype checking. Note that any type not available at runtime is located under the `googleapiclient._apis` package. \nFor example, `SheetsResource` should be imported from `googleapiclient._apis.sheets.v4.resources`.\nIf autocompleting import paths doesn\'t work you can find the correct path by using Mypy\'s [reveal_type](https://mypy.readthedocs.io/en/stable/common_issues.html#reveal-type)\non the thing you want to explicitly annotate. For `TypedDict`s this will also give you useful info about the structure of the dictionary.\n\n### Recursive types\nThe stubs previously didn\'t include recursive type definitions due to a lack of type checker support, but this is now included. Note that if you\'re using Mypy, v0.990 or higher is required for this to work.\n\n### Stubs for non-API-specific parts\nThere are detailed stubs for the API services, but other parts of the library have only been annotated with [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html),\nso they\'re mostly typed as `Any`. I believe these parts are mostly used internally by the library itself,\nso for most users this should be fine. Contributions to improve these stubs are welcome, though.\n',
    'author': 'Henrik Bruådal',
    'author_email': 'henrik.bruasdal@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/henribru/google-api-python-client-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
